@@ -15,19 +15,9 @@ NULL
 #'   \code{"name"}, and \code{"description"}
 #' \code{\link{syntax}} help file).
 #'
-#' @section Validating expressions:
-#' A \emph{validating expression} is an expression whose evaluation results in \code{TRUE}, \code{FALSE}
-#' or \code{NA}. 
 #' 
 #'  
-#'
-#' @seealso 
-#' \itemize{
-#'  \item{\code{\link{syntax}}} 
-#'  \item{\code{\link{confront}}}, \code{\link{check_that}}
-#'  \item{\code{\link{summary,expressionset-method}}}
-#'  \item{\code{\link{validator-class}}}
-#' }
+#' @family validator-methods
 #' @return An object of class \code{validator} (see \code{\link{validator-class}}).
 #' 
 #'
@@ -41,7 +31,8 @@ validator <- function(..., .file, .data) new('validator',...
 #' Store a set of rich validating rules.
 #'
 #' @section Details:
-#' A validator stores a set of validatin rules. It is a child class of \code{\link{expressionset}} and
+#' A validator stores a set of validatin rules. It is a child class of 
+#' \code{\link{expressionset}} and
 #' can be constructed with  \code{\link{validator}}.
 #'
 #' @section Exported S4 methods for \code{validator}:
@@ -171,7 +162,7 @@ get_linear_coefficients <- function(x, normalize=TRUE,...){
 #'
 #' @examples
 #' validator(x>0) + validator(x<=1)
-#'
+#' @family validator-methods
 #' @export
 setMethod("+", c("validator","validator"), function(e1, e2){
   v <- validator()
@@ -184,3 +175,129 @@ setMethod("+", c("validator","validator"), function(e1, e2){
 
 
 
+#' Plot a validator object
+#' 
+#' The matrix of variables x rules is plotted, in which rules that are
+#' recognized as linear (in)equations are differently colored. 
+#' The augmented matrix is returned, but can also be calculated using
+#' \code{variables(x, as="matrix")}.
+#' 
+#' @export
+#' @param x validator object with rules
+#' @param y not used
+#' @param use_blocks \code{logical} if \code{TRUE} the matrix is sorted
+#' according to the connected sub sets of variables (aka blocks).
+#' @param col \code{character} with color codes for plotting variables. 
+#' @param cex size of the variables plotted.
+#' @param show_legend should a legend explaining the colors be drawn?
+#' @param ... passed to image
+#' @return (invisible) the matrix
+#' @seealso \code{\link{variables}}
+#' @family validator-methods
+#' @family expressionset-methods
+#' @example ../examples/plot.R
+setMethod("plot","validator"
+  , function( x
+    , y
+    , use_blocks = TRUE
+    , col = c("#b2df8a", "#a6cee3") # Colorbrewer "Paired"
+    , cex = 1
+    , show_legend = TRUE
+    , ...
+    ){
+  
+  if (show_legend){  
+    oldpar <- par(xpd=TRUE, mar=c(7,4,3,3))
+    on.exit(par(oldpar))
+  }
+  
+  
+  use_blocks <- isTRUE(use_blocks)
+  show_legend <- isTRUE(show_legend)
+  
+  if (length(x) < 1){
+    message("No rules to be plotted")
+    return(invisible())
+  }
+  
+  blocks <- if (use_blocks){
+    x$blocks()
+  }
+  
+  A <- variables(x, as = "matrix")
+  
+  Z <- A
+  Z[A] <- 2
+  Z[A & x$is_linear()] <- 1
+  
+  is.na(Z) <- Z == 0
+  
+  if (use_blocks){
+    # change row order, so blocks are identifyable
+    rule_order <- unlist(blocks)
+    
+    var_order <- unlist(lapply(blocks, function(b){variables(x[b])}))
+    Z <- Z[rule_order, var_order, drop = FALSE]
+  }
+  Z <- t(Z)
+  
+  ylim <- c(1, ncol(Z)) + c(-0.5, 0.5)
+  # if (show_legend){
+  #   ylim[2] <- ylim[2] +  1 # needs extra space for legend
+  # }
+  
+  graphics::image( x = seq_len(nrow(Z))
+       , y = seq_len(ncol(Z))
+       , z = Z
+       , col = col
+       , las = 1
+       , xlab = "variables"
+       , ylab= "rules"
+       , xaxt = "n"
+       , yaxt = "n"
+  #     , ...
+       )
+  # label the y-axis with rule names
+  axis(2, at=seq_len(ncol(Z)), labels = colnames(Z), las=1)
+  
+  var_text <- which(Z > 0, arr.ind = TRUE)
+  var_text <- data.frame(var_text)
+  var_text$labels <- colnames(A)[var_text$variable]
+  # variables
+  text( x = var_text$variable
+      , y = var_text$rule
+      , labels = var_text$labels
+      , cex = cex
+      )
+  
+  if (use_blocks){
+    h <- sapply(x$blocks(), length)
+    h <- c(0,cumsum(h)) + 0.5
+    v <- lapply(blocks, function(b){variables(x[b])})
+    v <- sapply(v, length)
+    v <- c(0,cumsum(v)) + 0.5
+
+    graphics::rect( xleft = utils::head(v, -1)
+                  , xright = utils::tail(v, -1)
+                  , ybottom = utils::head(h, -1)
+                  , ytop = utils::tail(h, -1)
+                  , lty = 2
+                  , border ="gray30")
+  }
+  
+  if (show_legend){
+    legend( x = 0.5
+          , y = 0.2
+          , legend = c("linear rule", "other")
+          , fill=col
+          , bty="n"
+    )
+  }
+  
+  F <- factor(Z, levels=c(1,2), labels = c("linear", "other"))
+  dim(F) <- dim(Z)
+  dimnames(F) <- dimnames(Z)
+  
+  invisible(F)
+})
+
